==> pgbackrest_2.04.orig.tar.gz: pgbackrest-release-2.04/src/common/debug.c <==
/***********************************************************************************************************************************
Debug Routines
***********************************************************************************************************************************/
#include <stdio.h>

#include "common/debug.h"

/***********************************************************************************************************************************
Convert object to a zero-terminated string for logging
***********************************************************************************************************************************/
size_t
objToLog(const void *object, const char *objectName, char *buffer, size_t bufferSize)
{
    size_t result = 0;

    if (object == NULL)
        result = (size_t)snprintf(buffer, bufferSize, "null");
    else
        result = (size_t)snprintf(buffer, bufferSize, "{%s}", objectName);

    return result;
}

/***********************************************************************************************************************************
Convert pointer to a zero-terminated string for logging
***********************************************************************************************************************************/
size_t
ptrToLog(const void *pointer, const char *pointerName, char *buffer, size_t bufferSize)
{
    size_t result = 0;

    if (pointer == NULL)
        result = (size_t)snprintf(buffer, bufferSize, "null");
    else
        result = (size_t)snprintf(buffer, bufferSize, "(%s)", pointerName);

    return result;
}

/***********************************************************************************************************************************
Convert zero-terminated string for logging
***********************************************************************************************************************************/
size_t
strzToLog(const char *string, char *buffer, size_t bufferSize)
{
    return (size_t)snprintf(buffer, bufferSize, string == NULL ? "%s" : "\"%s\"", string == NULL ? "null" : string);
}

==> pgbackrest_2.10.orig.tar.gz: pgbackrest-release-2.10/src/common/debug.c <==
/***********************************************************************************************************************************
Debug Routines
***********************************************************************************************************************************/
#include <stdio.h>

#include "common/debug.h"

/***********************************************************************************************************************************
Convert object to a zero-terminated string for logging
***********************************************************************************************************************************/
size_t
objToLog(const void *object, const char *objectName, char *buffer, size_t bufferSize)
{
    size_t result = 0;

    if (object == NULL)
        result = (size_t)snprintf(buffer, bufferSize, "null");
    else
        result = (size_t)snprintf(buffer, bufferSize, "{%s}", objectName);

    return result;
}

/***********************************************************************************************************************************
Convert pointer to a zero-terminated string for logging
***********************************************************************************************************************************/
size_t
ptrToLog(const void *pointer, const char *pointerName, char *buffer, size_t bufferSize)
{
    size_t result = 0;

    if (pointer == NULL)
        result = (size_t)snprintf(buffer, bufferSize, "null");
    else
        result = (size_t)snprintf(buffer, bufferSize, "(%s)", pointerName);

    return result;
}

/***********************************************************************************************************************************
Convert zero-terminated string for logging
***********************************************************************************************************************************/
size_t
strzToLog(const char *string, char *buffer, size_t bufferSize)
{
    return (size_t)snprintf(buffer, bufferSize, string == NULL ? "%s" : "\"%s\"", string == NULL ? "null" : string);
}

/***********************************************************************************************************************************
Convert a type name to a zero-terminated string for logging
***********************************************************************************************************************************/
size_t
typeToLog(const char *typeName, char *buffer, size_t bufferSize)
{
    return (size_t)snprintf(buffer, bufferSize, "%s", typeName);
}
